Use Gobject Introspection in a virtualenv care of Vext, should work on all platforms.

Note:   
Vext is a workaround, you might want to check out pgi, which is based on cffi and
works in virtualenv - fill in the gaps and vext.gi won't be needed :)
